# -*- coding: utf-8 -*-
#
# Author: Lars B. Rollik <L.B.Rollik@protonmail.com>
# License: BSD 3-Clause
import logging

from rpi_camera_colony.tools.readers import read_session_data

__version__ = "0.4.1.dev0"
__author__ = "Lars B. Rollik"
